==> eagle-i-repository-webapp-1.0-MS6.02-sources.jar: jsp/repository/admin/memory_002dreport_jsp.java <==
package jsp.repository.admin;

import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.jsp.*;
import java.lang.management.*;
import java.util.*;
import java.io.IOException;

public final class memory_002dreport_jsp extends org.apache.jasper.runtime.HttpJspBase
    implements org.apache.jasper.runtime.JspSourceDependent {


    private void printCol(JspWriter oot, long data)
        throws IOException
    {

        oot.print("<td align=\"right\"><tt>");
        oot.print(String.format("%,-16d bytes", data));
        oot.print("</tt></td>");
    }
    private void doUsage(JspWriter oot, MemoryUsage mu, String label, boolean first)
        throws IOException
    {
        if (first)
            oot.println(
               "<tr>"+
               " <th width=\"20%\">&nbsp;</th>"+
               " <th  align=\"right\" width=\"20%\">Initial</th>"+
               " <th  align=\"right\" width=\"20%\">Used</th>"+
               " <th  align=\"right\" width=\"20%\">Committed</th>"+
               " <th  align=\"right\" width=\"20%\">Maximum</th>"+
               "</tr>");
        oot.println("<tr><th align=\"left\">"+label+"</th>");

        printCol(oot, mu.getInit());
        printCol(oot, mu.getUsed());
        printCol(oot, mu.getCommitted());
        printCol(oot, mu.getMax());

        oot.println("</tr>");
    }

  private static final JspFactory _jspxFactory = JspFactory.getDefaultFactory();

  private static java.util.List _jspx_dependants;

  private javax.el.ExpressionFactory _el_expressionfactory;
  private org.apache.AnnotationProcessor _jsp_annotationprocessor;

  public Object getDependants() {
    return _jspx_dependants;
  }

  public void _jspInit() {
    _el_expressionfactory = _jspxFactory.getJspApplicationContext(getServletConfig().getServletContext()).getExpressionFactory();
    _jsp_annotationprocessor = (org.apache.AnnotationProcessor) getServletConfig().getServletContext().getAttribute(org.apache.AnnotationProcessor.class.getName());
  }

  public void _jspDestroy() {
  }

  public void _jspService(HttpServletRequest request, HttpServletResponse response)
        throws java.io.IOException, ServletException {

    PageContext pageContext = null;
    HttpSession session = null;
    ServletContext application = null;
    ServletConfig config = null;
    JspWriter out = null;
    Object page = this;
    JspWriter _jspx_out = null;
    PageContext _jspx_page_context = null;


    try {
      response.setContentType("text/html");
      pageContext = _jspxFactory.getPageContext(this, request, response,
      			null, true, 8192, true);
      _jspx_page_context = pageContext;
      application = pageContext.getServletContext();
      config = pageContext.getServletConfig();
      session = pageContext.getSession();
      out = pageContext.getOut();
      _jspx_out = out;

      out.write("\n\n\n\n");
      out.write("\n<html>\n<head>\n  <title>JVM Memory Utilization</title>\n</head>\n<body>\n<h2 align=\"center\">JVM Memory Utilization</h2>\n<div align=\"center\">At Time: ");
      out.print( new Date().toString() );
      out.write("</div>\n<table border=\"0\" width=\"100%\">\n <tr><td bgcolor=\"#CCCCCC\" colspan=\"2\" align=\"center\"><h3>Memory MXBean</h3></td></tr>\n  <th width=\"20%\">Heap Memory Usage</td>\n   <td><tt>\n    ");
      out.print( ManagementFactory.getMemoryMXBean().getHeapMemoryUsage() );
      out.write("\n   </tt></td>\n </tr>\n <tr>\n  <th>Non-Heap Memory Usage</th>\n  <td><tt>\n   ");
      out.print( ManagementFactory.getMemoryMXBean().getNonHeapMemoryUsage() );
      out.write("\n  </td>\n </tr>\n <tr><td colspan=\"2\">&nbsp;</td></tr>\n <tr><td bgcolor=\"#CCCCCC\" colspan=\"2\" align=\"center\"><h3>Memory Pool MXBeans</h3></td></tr>\n");

        Iterator iter = ManagementFactory.getMemoryPoolMXBeans().iterator();
        while (iter.hasNext()) {
            MemoryPoolMXBean item = (MemoryPoolMXBean) iter.next();

      out.write("\n      <tr>\n       <td colspan=\"2\">\n         <table border=\"0\" width=\"80%\" align=\"center\" style=\"border: 1px #98AAB1 solid;\">\n           <tr>\n            <th colspan=\"5\" align=\"center\">\n              ");
      out.print( item.getName() );
      out.write(' ');
      out.write('(');
      out.print( item.getType() );
      out.write(")\n            </th>\n           </tr>\n\n           ");
 doUsage(out, item.getUsage(), "Usage", true); 
      out.write("\n           ");
 doUsage(out, item.getPeakUsage(), "Peak Usage", false); 
      out.write('\n');
      out.write('\n');
      MemoryUsage cu = item.getCollectionUsage();
        if (cu != null) {

      out.write("\n           ");
 doUsage(out, cu, "Collection Usage", false); 
      out.write('\n');
 } 
      out.write("\n         </table>\n      </td></tr>\n      <tr><td colspan=\"2\">&nbsp;</td></tr>\n");

}

      out.write("\n</table>\n</body>\n</html>\n");
    } catch (Throwable t) {
      if (!(t instanceof SkipPageException)){
        out = _jspx_out;
        if (out != null && out.getBufferSize() != 0)
          try { out.clearBuffer(); } catch (java.io.IOException e) {}
        if (_jspx_page_context != null) _jspx_page_context.handlePageException(t);
      }
    } finally {
      _jspxFactory.releasePageContext(_jspx_page_context);
    }
  }
}

==> eagle-i-repository-webapp-1.1-MS2.01-sources.jar: jsp/repository/admin/memory_002dreport_jsp.java <==
package jsp.repository.admin;

import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.jsp.*;
import java.lang.management.*;
import java.util.*;
import java.io.IOException;

public final class memory_002dreport_jsp extends org.apache.jasper.runtime.HttpJspBase
    implements org.apache.jasper.runtime.JspSourceDependent {


    private void printCol(JspWriter oot, long data)
        throws IOException
    {

        oot.print("<td align=\"right\"><tt>");
        oot.print(String.format("%,-16d bytes", data));
        oot.print("</tt></td>");
    }
    private void doUsage(JspWriter oot, MemoryUsage mu, String label, boolean first)
        throws IOException
    {
        if (first)
            oot.println(
               "<tr>"+
               " <th width=\"20%\">&nbsp;</th>"+
               " <th  align=\"right\" width=\"20%\">Initial</th>"+
               " <th  align=\"right\" width=\"20%\">Used</th>"+
               " <th  align=\"right\" width=\"20%\">Committed</th>"+
               " <th  align=\"right\" width=\"20%\">Maximum</th>"+
               "</tr>");
        oot.println("<tr><th align=\"left\">"+label+"</th>");

        printCol(oot, mu.getInit());
        printCol(oot, mu.getUsed());
        printCol(oot, mu.getCommitted());
        printCol(oot, mu.getMax());

        oot.println("</tr>");
    }

  private static final JspFactory _jspxFactory = JspFactory.getDefaultFactory();

  private static java.util.List _jspx_dependants;

  private javax.el.ExpressionFactory _el_expressionfactory;
  private org.apache.AnnotationProcessor _jsp_annotationprocessor;

  public Object getDependants() {
    return _jspx_dependants;
  }

  public void _jspInit() {
    _el_expressionfactory = _jspxFactory.getJspApplicationContext(getServletConfig().getServletContext()).getExpressionFactory();
    _jsp_annotationprocessor = (org.apache.AnnotationProcessor) getServletConfig().getServletContext().getAttribute(org.apache.AnnotationProcessor.class.getName());
  }

  public void _jspDestroy() {
  }

  public void _jspService(HttpServletRequest request, HttpServletResponse response)
        throws java.io.IOException, ServletException {

    PageContext pageContext = null;
    HttpSession session = null;
    ServletContext application = null;
    ServletConfig config = null;
    JspWriter out = null;
    Object page = this;
    JspWriter _jspx_out = null;
    PageContext _jspx_page_context = null;


    try {
      response.setContentType("text/html;charset=UTF-8");
      pageContext = _jspxFactory.getPageContext(this, request, response,
      			null, true, 8192, true);
      _jspx_page_context = pageContext;
      application = pageContext.getServletContext();
      config = pageContext.getServletConfig();
      session = pageContext.getSession();
      out = pageContext.getOut();
      _jspx_out = out;

      out.write("\n\n\n\n\n");
      out.write("\n<html>\n<head>\n    <meta http-equiv=\"content-type\" content=\"text/html; charset=UTF-8\"/>\n    <title>JVM Memory Utilization</title>\n</head>\n<body>\n<h2 align=\"center\">JVM Memory Utilization</h2>\n<div align=\"center\">At Time: ");
      out.print( new Date().toString() );
      out.write("</div>\n<table border=\"0\" width=\"100%\">\n <tr><td bgcolor=\"#CCCCCC\" colspan=\"2\" align=\"center\"><h3>Memory MXBean</h3></td></tr>\n  <th width=\"20%\">Heap Memory Usage</td>\n   <td><tt>\n    ");
      out.print( ManagementFactory.getMemoryMXBean().getHeapMemoryUsage() );
      out.write("\n   </tt></td>\n </tr>\n <tr>\n  <th>Non-Heap Memory Usage</th>\n  <td><tt>\n   ");
      out.print( ManagementFactory.getMemoryMXBean().getNonHeapMemoryUsage() );
      out.write("\n  </td>\n </tr>\n <tr><td colspan=\"2\">&nbsp;</td></tr>\n <tr><td bgcolor=\"#CCCCCC\" colspan=\"2\" align=\"center\"><h3>Memory Pool MXBeans</h3></td></tr>\n");

        Iterator iter = ManagementFactory.getMemoryPoolMXBeans().iterator();
        while (iter.hasNext()) {
            MemoryPoolMXBean item = (MemoryPoolMXBean) iter.next();

      out.write("\n      <tr>\n       <td colspan=\"2\">\n         <table border=\"0\" width=\"80%\" align=\"center\" style=\"border: 1px #98AAB1 solid;\">\n           <tr>\n            <th colspan=\"5\" align=\"center\">\n              ");
      out.print( item.getName() );
      out.write(' ');
      out.write('(');
      out.print( item.getType() );
      out.write(")\n            </th>\n           </tr>\n\n           ");
 doUsage(out, item.getUsage(), "Usage", true); 
      out.write("\n           ");
 doUsage(out, item.getPeakUsage(), "Peak Usage", false); 
      out.write('\n');
      out.write('\n');
      MemoryUsage cu = item.getCollectionUsage();
        if (cu != null) {

      out.write("\n           ");
 doUsage(out, cu, "Collection Usage", false); 
      out.write('\n');
 } 
      out.write("\n         </table>\n      </td></tr>\n      <tr><td colspan=\"2\">&nbsp;</td></tr>\n");

}

      out.write("\n</table>\n</body>\n</html>\n");
    } catch (Throwable t) {
      if (!(t instanceof SkipPageException)){
        out = _jspx_out;
        if (out != null && out.getBufferSize() != 0)
          try { out.clearBuffer(); } catch (java.io.IOException e) {}
        if (_jspx_page_context != null) _jspx_page_context.handlePageException(t);
      }
    } finally {
      _jspxFactory.releasePageContext(_jspx_page_context);
    }
  }
}
